<?php
/**
 * Theme functions and definitions
 *
 * @since 1.0.0
 */

if ( ! defined( 'IGNITION_BLOCKCHAIN_NAME' ) ) {
	/**
	 * The theme's slug.
	 */
	define( 'IGNITION_BLOCKCHAIN_NAME', 'ignition-blockchain' );
}

add_action( 'after_setup_theme', 'ignition_blockchain_setup' );
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function ignition_blockchain_setup() {
	// Default content width.
	$GLOBALS['content_width'] = 850;

	// Make theme available for translation.
	load_theme_textdomain( 'ignition-blockchain', get_template_directory() . '/languages' );

	// Image sizes
	set_post_thumbnail_size( 870, 580, true );
	add_image_size( 'ignition_item', 615, 410, true );
	add_image_size( 'ignition_item_lg', 1170, 780, true );
	add_image_size( 'ignition_article_media', 510, 510, true );
	add_image_size( 'ignition_minicart_item', 160, 160, true );

	add_theme_support( 'editor-styles' );

	$suffix = ignition_blockchain_ignition_scripts_styles_suffix();
	add_editor_style( "inc/assets/css/admin/editor-styles{$suffix}.css" );

	// Post types/modules.
	add_theme_support( 'ignition-gsection', array(
		'locations' => array(
			'header',
			'sidebar',
			'footer',
		),
	) );
	add_theme_support( 'ignition-event' );
	add_theme_support( 'ignition-portfolio' );
	add_theme_support( 'ignition-service' );
	add_theme_support( 'ignition-team' );
	// Typography.
	add_theme_support( 'ignition-typography-page-title' );
	add_theme_support( 'ignition-typography-navigation' );
	add_theme_support( 'ignition-typography-button' );
	// Colors.
	add_theme_support( 'ignition-site-colors-secondary' );

	add_theme_support( 'editor-color-palette', array(
		array(
			'name'  => __( 'Primary color', 'ignition-blockchain' ),
			'slug'  => 'theme-primary',
			'color' => '#31356b',
		),
		array(
			'name'  => __( 'Secondary color', 'ignition-blockchain' ),
			'slug'  => 'theme-secondary',
			'color' => '#019afe',
		),
		array(
			'name'  => __( 'Dark gray', 'ignition-blockchain' ),
			'slug'  => 'theme-dark-gray',
			'color' => '#242424',
		),
		array(
			'name'  => __( 'Medium gray', 'ignition-blockchain' ),
			'slug'  => 'theme-medium-gray',
			'color' => '#585858',
		),
		array(
			'name'  => __( 'Light gray', 'ignition-blockchain' ),
			'slug'  => 'theme-light-gray',
			'color' => '#dddddd',
		),
		array(
			'name'  => __( 'White', 'ignition-blockchain' ),
			'slug'  => 'white',
			'color' => '#ffffff',
		),
		array(
			'name'  => __( 'Black', 'ignition-blockchain' ),
			'slug'  => 'black',
			'color' => '#000000',
		),
	) );

	// Make sure WooCommerce detects theme support properly. Do not remove this line.
	// add_theme_support( 'woocommerce' );
}

/**
 * Theme includes.
 */
require_once get_theme_file_path( '/inc/inc.php' );
