<?php
/**
 * Shortcode definitions
 *
 * @since 1.0.0
 */

add_shortcode( 'crypto-table', 'ignition_blockchain_shortcode_crypto_table' );
/**
 * Builds the Crypto Table shortcode output.
 *
 * @since 1.0.0
 *
 * @param array       $params
 * @param null|string $content
 * @param string      $shortcode
 *
 * @return string The crypto table.
 */
function ignition_blockchain_shortcode_crypto_table( $params, $content, $shortcode ) {
	$params = shortcode_atts( array(
		'limit' => '15', // 0 for unlimited
		'start' => '', // Start from this currency, e.g. 10 = start from the 10th
		'fiat'  => 'USD',
	), $params, $shortcode );

	$start = (int) $params['start'];
	$start = $params['start'] < 1 ? 1 : $params['start'];
	$limit = $params['limit'];
	$fiat  = $params['fiat'];

	$q_params = array(
		'limit'   => $limit,
		'start'   => $start,
		'convert' => $fiat,
	);

	wp_enqueue_script( 'sorttable' );

	$endpoint = 'cryptocurrency/listings/latest';

	$response = ignition_blockchain_coinmarketcap_get_data( $endpoint, $q_params );

	ob_start();

	if ( false === $response['error'] ) {
		$response_data = $response['data'];
		if ( ! empty( $response_data['data'] ) && is_array( $response_data['data'] ) ) {
			?>
			<div class="table-list-crypto-wrap">
				<table
					class="table-list-crypto table-styled sortable"
					data-currency="<?php echo esc_attr( $fiat ); ?>"
					data-limit="<?php echo esc_attr( $limit ); ?>"
				>
					<thead>
						<tr>
							<th><?php esc_html_e( 'Rank', 'ignition-blockchain' ); ?><span class="table-sort-icon"></span></th>
							<th><?php esc_html_e( '(Symbol) Name', 'ignition-blockchain' ); ?><i class="table-sort-icon"></i></th>
							<th><?php esc_html_e( 'Market Cap', 'ignition-blockchain' ); ?><i class="table-sort-icon"></i></th>
							<th><?php esc_html_e( 'Price', 'ignition-blockchain' ); ?><i class="table-sort-icon"></i></th>
							<th><?php esc_html_e( 'Volume (24h)', 'ignition-blockchain' ); ?><i class="table-sort-icon"></i></th>
							<th><?php esc_html_e( 'Change (24h)', 'ignition-blockchain' ); ?><i class="table-sort-icon"></i></th>
						</tr>
					</thead>

					<tbody>
						<?php
							$i = 0;
							foreach ( $response_data['data'] as $coin ) {
								$i++;
								$even_odd = $i % 2 ? 'odd' : 'even';

								$price      = $coin['quote'][ $fiat ]['price'];
								$market_cap = $coin['quote'][ $fiat ]['market_cap'];
								$volume     = $coin['quote'][ $fiat ]['volume_24h'];
								$change_24h = $coin['quote'][ $fiat ]['percent_change_24h'];

								$change_class = '';
								if ( floatval( $change_24h ) < 0 ) {
									$change_class = 'text-danger symbol-desc';
								} elseif ( floatval( $change_24h ) > 0 ) {
									$change_class = 'text-success symbol-asc';
								} else {
									$change_class = '';
								}
								?>
								<tr role="row" class="<?php echo esc_attr( $even_odd ); ?>">
									<td><?php echo esc_html( $coin['cmc_rank'] ); ?></td>
									<td>(<strong><?php echo esc_html( $coin['symbol'] ); ?></strong>) <?php echo esc_html( $coin['name'] ); ?></td>
									<td><?php echo esc_html( ignition_blockchain_coinmarketcap_format_currency_number( $market_cap, $fiat, 0 ) ); ?></td>
									<td><?php echo esc_html( ignition_blockchain_coinmarketcap_format_currency_number( $price, $fiat ) ); ?></td>
									<td><?php echo esc_html( ignition_blockchain_coinmarketcap_format_currency_number( $volume, $fiat ) ); ?></td>
									<td data-sorttable_customkey="<?php echo floatval( $change_24h ); ?>"><span class="<?php echo esc_attr( $change_class ); ?>"><?php echo esc_html( sprintf( '%.2f%%', abs( $change_24h ) ) ); ?></span></td>
								</tr>
								<?php
							}
						?>
					</tbody>
				</table>
			</div>
		<?php
		}
	} elseif ( true === $response['error'] && is_user_logged_in() && current_user_can( 'edit_theme_options' ) ) {
		foreach ( $response['errors'] as $error_msg ) {
			echo wp_kses_post( sprintf( '<p class="ignition-blockchain-coinmarketcap-error">%s</p>', $error_msg ) );
		}
	}

	$output = ob_get_clean();

	return $output;
}
