<?php
/**
 * Ignition_Blockchain_Widget_Coinmarketcap_Global class
 *
 * @since 1.0.0
 */

/**
 * Class used to implement the Global Crypto Info widget.
 *
 * @since 1.0.0
 *
 * @see Ignition_Widget
 * @see WP_Widget
 */
class Ignition_Blockchain_Widget_Coinmarketcap_Global extends Ignition_Widget {

	protected $defaults = array(
		'title' => '',
		'fiat'  => 'USD',
	);

	public function __construct() {
		$widget_ops  = array( 'description' => esc_html__( 'Displays global cryptocurrency information.', 'ignition-blockchain' ) );
		$control_ops = array();
		parent::__construct( 'ignition-blockchain-coinmarketcap-global', esc_html__( 'Theme - Global Crypto Info', 'ignition-blockchain' ), $widget_ops, $control_ops );
	}

	public function widget( $args, $instance ) {
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$id            = isset( $args['id'] ) ? $args['id'] : '';
		$before_widget = $args['before_widget'];
		$after_widget  = $args['after_widget'];

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		$fiat = $instance['fiat'];

		echo wp_kses( $before_widget, ignition_get_allowed_sidebar_wrappers() );

		if ( $title ) {
			echo wp_kses( $args['before_title'] . $title . $args['after_title'], ignition_get_allowed_sidebar_wrappers() );
		}

		$endpoint = 'global-metrics/quotes/latest';
		$params   = array(
			'convert' => $fiat,
		);

		$response = ignition_blockchain_coinmarketcap_get_data( $endpoint, $params );

		if ( false === $response['error'] ) {
			if ( is_array( $response['data']['data'] ) ) {
				$data = $response['data']['data'];

				?>
				<div class="widget-crypto widget-crypto-data loaded" data-currency="<?php echo esc_attr( $fiat ); ?>"
					data-metrics="total_market_cap,total_volume_24h,btc_dominance,active_cryptocurrencies,active_market_pairs">
					<div class="widget-crypto-placeholder">
						<div class="data-item-wrap">

							<div class="data-item">
								<?php $metric = 'total_market_cap'; ?>
								<span class="data-item-eyebrow"><?php esc_html_e( 'Market Cap', 'ignition-blockchain' ); ?></span>
								<span class="data-item-value"><?php echo esc_html( ignition_blockchain_coinmarketcap_format_currency_number( $data['quote'][ $fiat ][ $metric ], $fiat, 0 ) ); ?></span>
							</div>

							<div class="data-item">
								<?php $metric = 'total_volume_24h'; ?>
								<span class="data-item-eyebrow"><?php esc_html_e( '24h Volume', 'ignition-blockchain' ); ?></span>
								<span class="data-item-value"><?php echo esc_html( ignition_blockchain_coinmarketcap_format_currency_number( $data['quote'][ $fiat ][ $metric ], $fiat, 0 ) ); ?></span>
							</div>

							<div class="data-item">
								<?php $metric = 'btc_dominance'; ?>
								<span class="data-item-eyebrow"><?php esc_html_e( 'BTC Coverage', 'ignition-blockchain' ); ?></span>
								<span class="data-item-value"><?php echo esc_html( $data[ $metric ] . '%' ); ?></span>
							</div>

							<div class="data-item">
								<?php $metric = 'active_cryptocurrencies'; ?>
								<span class="data-item-eyebrow"><?php esc_html_e( 'Total Active Currencies', 'ignition-blockchain' ); ?></span>
								<span class="data-item-value"><?php echo esc_html( number_format_i18n( $data[ $metric ] ) ); ?></span>
							</div>

							<div class="data-item">
								<?php $metric = 'active_market_pairs'; ?>
								<span class="data-item-eyebrow"><?php esc_html_e( 'Active Markets', 'ignition-blockchain' ); ?></span>
								<span class="data-item-value"><?php echo esc_html( number_format_i18n( $data[ $metric ] ) ); ?></span>
							</div>

						</div>

						<p class="data-last-updated">
							<?php esc_html_e( 'Last update:', 'ignition-blockchain' ); ?>
							<span class="data-last-updated-value">
								<?php
									$timestamp = strtotime( $data['last_updated'] );
									echo esc_html( date_i18n( get_option( 'date_format' ) . ', ' . get_option( 'time_format' ), ignition_blockchain_convert_gmt_to_local_timestamp( $timestamp ) ) );
								?>
							</span>
						</p>
					</div>
				</div>
				<?php
			}
		} elseif ( true === $response['error'] && is_user_logged_in() && current_user_can( 'edit_theme_options' ) ) {
			foreach ( $response['errors'] as $error_msg ) {
				echo wp_kses_post( sprintf( '<p class="ignition-blockchain-coinmarketcap-error">%s</p>', $error_msg ) );
			}
		}

		echo wp_kses( $after_widget, ignition_get_allowed_sidebar_wrappers() );
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['fiat']  = ignition_blockchain_coinmarketcap_sanitize_fiat_currency( $new_instance['fiat'] );

		return $instance;
	}

	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$this->field_input_text( 'title', array(
			'title' => __( 'Title:', 'ignition-blockchain' ),
			'value' => $instance['title'],
		) );

		$this->field_dropdown( 'fiat', array(
			'title'        => __( 'Show values expressed in:', 'ignition-blockchain' ),
			'value'        => $instance['fiat'],
			'choices'      => ignition_blockchain_coinmarketcap_get_fiat_currencies(),
			'select_class' => 'widefat',
		) );
	}
}
